parse_formula: Parse formula for brokenstick model

View source: R/internals.R

parse_formulaR Documentation

Parse formula for brokenstick model

Description

A bare bones formula parser to extract variables names from formulas of y ~ x | g. It return the name of the first variable mentioned in each formula component.

Usage

parse_formula(f)

Arguments

f

formula object

Value

A list with elements x, y and g. Each element has length 1.

Author(s)

Stef van Buuren 2023


brokenstick documentation built on March 13, 2026, 5:06 p.m.